summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/2608intf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/2608intf.cpp')
-rw-r--r--src/devices/sound/2608intf.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/2608intf.cpp b/src/devices/sound/2608intf.cpp
index 1bc634d34c2..4ca366fa117 100644
--- a/src/devices/sound/2608intf.cpp
+++ b/src/devices/sound/2608intf.cpp
@@ -63,10 +63,10 @@ void ym2608_device::timer_handler(int c,int count,int clock)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void ym2608_device::stream_generate(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym2608_device::stream_generate(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
ym2608_update_one(m_chip, outputs, samples);
}
@@ -93,7 +93,7 @@ void ym2608_device::device_start()
m_timer[1] = timer_alloc(1);
/* stream system initialize */
- m_stream = machine().sound().stream_alloc(*this,0,2,rate, stream_update_delegate(&ym2608_device::stream_generate,this));
+ m_stream = machine().sound().stream_alloc_legacy(*this,0,2,rate, stream_update_legacy_delegate(&ym2608_device::stream_generate,this));
/* initialize YM2608 */
m_chip = ym2608_init(this,clock(),rate,
@@ -63,10 +63,10 @@ void ym2608_device::timer_handler(int c,int count,int clock)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------